@@ -1,7 +1,7 @@
 """qtbot should work for testing!"""
 
 from threading import Thread, current_thread, main_thread
-from typing import TYPE_CHECKING, Any, Callable, Literal, Tuple
+from typing import TYPE_CHECKING, Any, Callable, Literal
 from unittest.mock import Mock
 
 import pytest
@@ -14,7 +14,7 @@ if TYPE_CHECKING:
     from pytestqt.qtbot import QtBot
 
 
-def _equals(*val: Any) -> Callable[[Tuple[Any, ...]], bool]:
+def _equals(*val: Any) -> Callable[[tuple[Any, ...]], bool]:
     def _inner(*other: Any) -> bool:
         return other == val
 
